@@ -67,7 +67,7 @@ GuiPainter::~GuiPainter()
 
 
 void GuiPainter::setQPainterPen(QColor const & col,
-	Painter::line_style ls, int lw)
+	Painter::line_style ls, int lw, Qt::PenJoinStyle js)
 {
 	if (col == current_color_ && ls == current_ls_ && lw == current_lw_)
 		return;
@@ -89,6 +89,8 @@ void GuiPainter::setQPainterPen(QColor const & col,
 
 	pen.setWidth(lw);
 
+	pen.setJoinStyle(js);
+
 	setPen(pen);
 }
 
@@ -266,7 +268,7 @@ void GuiPainter::rectangle(int x, int y, int w, int h,
 	line_style ls,
 	int lw)
 {
-	setQPainterPen(computeColor(col), ls, lw);
+	setQPainterPen(computeColor(col), ls, lw, Qt::MiterJoin);
 	drawRect(x, y, w, h);
 }
 
@@ -418,7 +420,7 @@ void GuiPainter::text(int x, int y, docstring const & s,
 		// Morover the first/last element is possibly not the right one since the glyph may have changed.
 		int const lb = min(fm.lbearing(s[0]), 0);
 		int const mA = fm.maxAscent();
-		if (QPixmapCache::find(key, pm)) {
+		if (QPixmapCache::find(key, &pm)) {
 			// Draw the cached pixmap.
 			drawPixmap(x + lb, y - mA, pm);
 			return;
@@ -563,8 +565,8 @@ void GuiPainter::buttonText(int x, int baseline, docstring const & s,
 
 	static int const d = offset / 2;
 
-	fillRectangle(x + d + 1, baseline - ascent + 1, width - offset - 1,
-			      ascent + descent - 1, back);
+	fillRectangle(x + d, baseline - ascent, width - offset,
+			      ascent + descent, back);
 	rectangle(x + d, baseline - ascent, width - offset, ascent + descent, frame);
 	text(x + offset, baseline, s, font);
 }
